# This file defines overlays
{inputs, ...}: {
  # This one brings our custom packages from the 'pkgs' directory
  additions = final: _prev: import ../packages final.pkgs;

  modifications = final: prev: {

    networkmanager = prev.pkgs.unstable.networkmanager;

    ulauncher = prev.ulauncher.overrideAttrs (old: {
      propagatedBuildInputs = with prev.python3Packages;
        old.propagatedBuildInputs
        ++ [
          thefuzz
          tornado
        ];
    });

    gnome47Extensions.paperwm = inputs.paperwm.packages.x86_64-linux.default;

    wineWowPackages.stagingFull = prev.wineWowPackages.stagingFull.overrideAttrs (old: {
      patches = old.patches ++ [ ./wine-6006.patch ];
      waylandSupport = true;
      fontconfigSupport = true;
      vulkanSupport = true;
    });

    raylib = prev.raylib.overrideDerivation (previous: {
      src = prev.fetchFromGitHub {
        owner = "raysan5";
        repo = "raylib";
        hash = "sha256-PHYdAEhittShd1UhASdhmq0nGHEEVZEUGcjCUUJZl9g=";
        rev = "c9c830cb971d7aa744fe3c7444b768ccd5176c4c";
      };
      patches = [""];
    });

    openrazer-daemon = prev.openrazer-daemon.overrideDerivation (previous: {
	    # name = "openrazer-daemon";
	    src = prev.fetchFromGitHub {
	      owner = "openrazer";
        version = "latest";
	      repo = "openrazer";
	      hash = "sha256-GqmFpVNuPRNM95pJsihsk/d3s61t4Lw+qaukKip9BAM=";
	      rev = "5e677b178be7da08fb72d7cd0791bf68a129fcc5";
	    };
	  });
  };

  emacs-overlay = (import (builtins.fetchTarball {
    url = "https://github.com/nix-community/emacs-overlay/archive/master.tar.gz";
    sha256 = "1dqzv0rlw4vsyr0h0879ayglcma8qk5m24mf89c6zd7x0x2ivq75";
  }));

  # When applied, the unstable nixpkgs set (declared in the flake inputs) will
  # be accessible through 'pkgs.unstable'
  unstable-packages = final: _prev: {
    unstable = import inputs.nixpkgs-unstable {
      system = final.system;
      config.allowUnfree = true;
    };
  };
}
